# Copyright (C) 2005 JanRain, Inc.
# Copyright (C) 2009, 2010 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from apache_openid.logging import debug, error
from apache_openid.handlers.openid.authenticator import Authenticator
from apache_openid.handlers.openidteams.mixins import CookiedTeamsMixin


class TeamsAuthenticator(Authenticator, CookiedTeamsMixin):
    def __init__(self, request, options, session):
        super(TeamsAuthenticator, self).__init__(request, options)
        self.session = session

    def authenticate(self, openid):
        """Check to see if any of the cookied teams are authorized."""
        if openid is None:
            # If we don't have an openid url, they haven't authenticated,
            # therefore the are not authorized
            debug('Auth failed: no openid URL given')
            return False
        elif super(TeamsAuthenticator, self).authenticate(openid):
            # Check if the user has been authorized first, since this is
            # cheaper than checking team memberships
            debug('Auth passed: user %s already authenticated', openid)
            return True
        elif len(self.authorized_teams) > 0 and \
            self.check_team_entitlement(self.authorized_teams,
                                        self.cookied_teams):
            # Finally check to see if the user is a member of an authorized
            # team
            debug('Auth passed: user is a member of an authorized team')
            return True
        else:
            # If none of the above pass, the user is not authorized
            debug('Auth failed: no matching authorized team or user')
            return False

    def check_team_entitlement(self, allowed_teams, user_teams):
        debug("Allowed Teams: %r", allowed_teams)
        debug("User Teams: %r", user_teams)
        for team in user_teams:
            if team in allowed_teams:
                debug('User %r is a member of team %r',
                    self.request.cookied_user, team)
                return True
        debug('%s is not a member of an allowed team',
              self.request.cookied_user)
        debug('Access denied to %r for %r (teams: %r)',
            self.request.uri, self.request.cookied_user, user_teams)
        return False
